@@ -12,8 +12,12 @@ import locale
 import copy
 from datetime import datetime
 from collections import OrderedDict
-from io import StringIO
 from csv import DictWriter
+try:
+    # Python 2 support
+    from cStringIO import StringIO
+except ImportError:
+    from io import StringIO
 
 import dateparser
 import click
@@ -34,7 +38,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License."""
 
-__version__ = "1.2.0"
+__version__ = "1.2."
 
 locale.setlocale(locale.LC_ALL, '')
 
@@ -193,7 +197,7 @@ def _load_json(dnsdb_json_string, sort_by=None, reverse=False):
         try:
             results = list(sorted(
                 results,
-                key=lambda x: x[sort_by], reverse=reverse)).copy()
+                key=lambda x: x[sort_by], reverse=reverse))
         except KeyError:
             raise KeyError("Unable to sort by {0}. "
                            "Field does not exist".format(sort_by))
@@ -299,23 +303,24 @@ def dnsdb_results_to_csv(results):
         str: Results in CSV format
     """
     results = copy.deepcopy(results)
-    file = StringIO()
+    csv_file = StringIO()
     fields = ["bailiwick", "count", "first_seen", "last_seen", "source",
               "rrname", "rrtype", "rdata"]
-    csv = DictWriter(file, fieldnames=fields)
+    csv = DictWriter(csv_file, fieldnames=fields)
     csv.writeheader()
     for result in results:
         if "first_seen" in result:
             result["first_seen"] = _timestamp_to_iso8601(result["first_seen"])
-        if "last_seen" in results:
+        if "last_seen" in result:
             result["last_seen"] = _timestamp_to_iso8601(result["last_seen"])
         if "rdata" in result:
-            result["rdata"] = "|".join(result["rdata"])
+            if type(result["rdata"]) == list:
+                result["rdata"] = "|".join(result["rdata"])
         csv.writerow(result)
 
-    file.seek(0)
+    csv_file.seek(0)
 
-    return file.read()
+    return csv_file.read()
 
 
 class DNSDBAPI(object):
@@ -365,7 +370,7 @@ class DNSDBAPI(object):
              sort_by=None, reverse=False):
         default_params = dict(swclient=self.client_name,
                               version=self.client_version)
-        _params = default_params.copy()
+        _params = copy.deepcopy(default_params)
         if params:
             _params.update(params)
         endpoint = "{0}/{1}".format(self._root, endpoint.strip("/"))
@@ -492,7 +497,12 @@ class DNSDBAPI(object):
         Performs a inverse DNS lookup
 
         Args:
-            _type (str): ``name``, ``ip``, or ``raw``
+            _type (str): One of the following:
+
+                - ``name``: A DNS domain name (use ``*`` as a wildcard)
+                - ``ip``: An IPv4 or IPv6 address, range, or CIDR notation
+                - ``raw``: An even number of hexadecimal digits
+
             value (str): The rdata value to search for
             rrtype (str): The DNS Resource Record type
             first_seen_before (str): Filter results first seen before this date
@@ -514,7 +524,9 @@ class DNSDBAPI(object):
             params["limit"] = limit
         _type = _type.lower()
         if _type not in ["name", "ip", "raw"]:
-            raise ValueError("_type must be name ip or raw")
+            raise ValueError("_type must be name, ip, or raw")
+        if _type == "ip":
+            value = value.replace("/", ",").replace("\\", ",")
         endpoint = "/lookup/rdata/{0}/{1}".format(_type, value)
         if rrtype is not None:
             endpoint += "/{0}".format(rrtype)
@@ -628,15 +640,14 @@ def _forward_lookup(ctx, owner_name, rrtype="ANY", bailiwick=None,
         )
         if len(output_paths) == 0:
             if _format == "json":
-                print(dnsdb_results_to_json(results.copy()))
+                print(dnsdb_results_to_json(results))
             elif _format == "csv":
-                print(dnsdb_results_to_csv(results.copy()))
+                print(dnsdb_results_to_csv(results))
             else:
-                print(dnsdb_results_to_text(results.copy()))
+                print(dnsdb_results_to_text(results))
         else:
             for output_path in output_paths:
-                with open(output_path, "w",
-                          encoding="utf-8", newline="\n") as output_file:
+                with open(output_path, "w") as output_file:
                     if output_path.lower().endswith(".json"):
                         output_file.write(dnsdb_results_to_json(results))
                     elif output_path.lower().endswith(".csv"):
